@@ -1,5 +1,5 @@
 package Adapter::Async::OrderedList::Array;
-$Adapter::Async::OrderedList::Array::VERSION = '0.018';
+$Adapter::Async::OrderedList::Array::VERSION = '0.019';
 use strict;
 use warnings;
 
@@ -165,6 +165,17 @@ sub find_insert_pos {
 	return defined($idx) ? Future->done($idx) : Future->fail('not found');
 }
 
+sub extract_first_by {
+	my ($self, $code, $start_idx) = @_;
+	$start_idx //= 0;
+	for my $idx ($start_idx..$#{$self->{data}}) {
+		if(grep $code->($_), $self->{data}[$idx]) {
+			return Future->done(CORE::splice @{$self->{data}}, $idx, 1);
+		}
+	}
+	return Future->done;
+}
+
 1;
 
 __END__
